// importing necessary modules I used for this graph.
import { getData } from './getData';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// declaring constants by reading svg tag from index.html
const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// Start rendering pie chart to html
const render = (data,total) => {
  //
  const pieData = pie().value(d=>d.deadth)(data);
  
	// Colors for in Pie Chart
  const colors = scaleOrdinal()
  	.domain(data)
  	.range([
      "#FFD700","#018670","#B22222","#8dc63f","#f58026",
      "#4b4b4b","#9acbc2","#00b5cc","#014140","#d9d5d5",
      "#9400D3","#CD5C5C","#6495ED","#CCCCFF","#FFBF00"
    ]);
  
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(170)
  	.padAngle(0)
  	.padRadius(0);
  // Rendering section of pie chart
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  
  // Rendering color to the section to pie chart
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.death));
  
  // Redering legends for pie chart
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*25})`;
    });
  
  
  //redering legend colors to pie chart 
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.death));
  
  //Redering legends brands text  
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.country);
  
  
}




// load data from gist link by using helper class getData 
const run = async () => {
  let data = await getData()
  let total = 0
  data.forEach(d=>{
    d.internetuserate = +d.internetuserate;
    total += d.internetuserate
  });
	render(data,total);
};

//Initial Function call to render pie chart 
run();